@@ -15,7 +15,7 @@ use EPublisher::Source::Base;
 
 our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = 0.2;
+our $VERSION = 0.3;
 
 # implementing the interface to EPublisher::Source::Base
 sub load_source{
@@ -67,7 +67,7 @@ sub load_source{
         "103: passed info: "
         . "filename => $name, "
         . "title => $title, "
-        . "pod => $pod"
+        . 'pod => ' . substr($pod, 0, 30) . '<<<<CUT<<<<'
     );
 
     return @pod;
@@ -85,7 +85,7 @@ EPublisher::Source::Plugin::PerltutsCom - Get POD from tutorials published on pe
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
